==> poetry_git_version_plugin-0.0.3-py3-none-any.whl: poetry_git_version_plugin/plugins.py <==
from __future__ import annotations

from cleo.io.io import IO
from cleo.io.outputs.output import Verbosity
from poetry.plugins.application_plugin import ApplicationPlugin
from poetry.plugins.plugin import Plugin
from poetry.poetry import Poetry

from poetry_git_version_plugin import config
from poetry_git_version_plugin.commands import GitVersionCommand
from poetry_git_version_plugin.exceptions import PluginException, plugin_exception_wrapper
from poetry_git_version_plugin.services import GitVersionService


class PoetryGitVersionPlugin(Plugin):
    """Плагин определения версии по гит тегу"""

    @plugin_exception_wrapper
    def activate(self, poetry: Poetry, io: IO):
        io.write_line(f'<b>{config.PLUGIN_NAME}</b>: Init', Verbosity.VERBOSE)

        self.plugin_config = config.PluginConfig(poetry.pyproject)

        try:
            tag = GitVersionService(io, self.plugin_config).get_tag()

        except Exception as ex:
            if self.plugin_config.ignore_exception:
                if isinstance(ex, PluginException):
                    text = '<b>{0}</b>: {1}. Ignore Exception\n'.format(config.PLUGIN_NAME, ex.args[0])

                else:
                    text = '<b>{0}</b>: {1}: {2}. Ignore Exception\n'.format(
                        config.PLUGIN_NAME, ex.__class__.__name__, '; '.join(ex.args) if ex.args else 'None'
                    )

                io.write_error(text, Verbosity.VERBOSE)
                return

            raise ex

        if tag is not None:
            poetry.package.version = tag

        io.write_line(f'<b>{config.PLUGIN_NAME}</b>: Finished\n', Verbosity.VERBOSE)


class PoetryGitVersionApplicationPlugin(ApplicationPlugin):
    commands = [GitVersionCommand]

==> poetry_git_version_plugin-0.1.4.dev2-py3-none-any.whl: poetry_git_version_plugin/plugins.py <==
from __future__ import annotations

from cleo.io.io import IO
from cleo.io.outputs.output import Verbosity
from poetry.plugins.application_plugin import ApplicationPlugin
from poetry.plugins.plugin import Plugin
from poetry.poetry import Poetry

from poetry_git_version_plugin import config
from poetry_git_version_plugin.commands import GitVersionCommand
from poetry_git_version_plugin.exceptions import PluginException, plugin_exception_wrapper
from poetry_git_version_plugin.services import GitVersionService
from poetry.core.constraints.version import Version


class PoetryGitVersionPlugin(Plugin):
    """Плагин определения версии по гит тегу"""

    @plugin_exception_wrapper
    def activate(self, poetry: Poetry, io: IO):
        io.write_line(f'<b>{config.PLUGIN_NAME}</b>: Init', Verbosity.VERBOSE)

        plugin_config = config.PluginConfig(poetry.pyproject)

        try:
            version = GitVersionService(io, plugin_config).get_version()
            poetry.package.version = Version.parse(version)

        except Exception as ex:
            if plugin_config.ignore_errors:
                if not isinstance(ex, PluginException):
                    ex = PluginException(ex)

                io.write_error_line(f'{ex}. Ignore Exception\n', Verbosity.VERBOSE)

                return

            raise ex

        io.write_error_line(f'<b>{config.PLUGIN_NAME}</b>: Finished\n', Verbosity.VERBOSE)


class PoetryGitVersionApplicationPlugin(ApplicationPlugin):
    commands = [GitVersionCommand]
